@@ -94,11 +94,11 @@
       (bg-cyan-intense    "#88c8ff")
 
       (bg-red-subtle      "#ffcfbf")
-      (bg-green-subtle    "#afffbf")
-      (bg-yellow-subtle   "#fff576")
-      (bg-blue-subtle     "#ccdfff")
-      (bg-magenta-subtle  "#ffddff")
-      (bg-cyan-subtle     "#bfefff")
+      (bg-green-subtle    "#aff7c5")
+      (bg-yellow-subtle   "#f9f376")
+      (bg-blue-subtle     "#cfdff9")
+      (bg-magenta-subtle  "#f9ddf0")
+      (bg-cyan-subtle     "#bfeaf0")
 
 ;;; Diffs
 
@@ -208,11 +208,13 @@
 
       (date-common cyan-cooler)
       (date-deadline red)
+      (date-deadline-subtle red-faint)
       (date-event fg-alt)
       (date-holiday magenta-warmer)
       (date-now fg-main)
       (date-range fg-alt)
       (date-scheduled yellow)
+      (date-scheduled-subtle yellow-faint)
       (date-weekday cyan)
       (date-weekend red-faint)
 
